﻿-- ----------------------------------------------------------------------------
-- GridStatusIgnored by Cyprias
-- ----------------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("GridStatusIgnored")

GridStatusIgnored = GridStatus:NewModule("GridStatusIgnored")

L:RegisterTranslations("enUS", function() return {
	["Ignored"] = true,
} end)


GridStatusIgnored.menuName = L["Ignored"]


GridStatusIgnored.defaultDB = {
	debug = false,
	alert_ignored = {
		text =  L["Ignored"],
		enable = true,
		color = { r = 0.5, g = 0.5, b = 0.5, a = 0.3 },
		priority = 100,
		range = false,
	}
}

GridStatusIgnored.options = false

local ignoredNames = {}

function GridStatusIgnored:OnInitialize()
	self.super.OnInitialize(self)
	self:RegisterStatus("alert_ignored", L["Ignored"], nil, true)
end

function GridStatusIgnored:OnEnable()
	GridStatusIgnored:UpdateIgnoreList()
	
	self:RegisterEvent("PARTY_MEMBERS_CHANGED")
--~ 	self:RegisterEvent("IGNORELIST_UPDATE") --Users of IgnoreMore don't get this event, so instead I'm hooking IgnoreList_Update().
	self:RegisterEvent("RAID_ROSTER_UPDATE")
end

function GridStatusIgnored:UpdateIgnoreList()
	ignoredNames = {}; --reset, maybe they removed someone.
	local iName;
	for i=1, GetNumIgnores() do
		iName = GetIgnoreName(i);
		if iName then--would this ever not exist?
			ignoredNames[self:GetJustName(iName)] = true;
		end
	end
end

--~ function GridStatusIgnored:IGNORELIST_UPDATE()
--~ 	self:PARTY_MEMBERS_CHANGED()
--~ end

function GridStatusIgnored:RAID_ROSTER_UPDATE()
	self:PARTY_MEMBERS_CHANGED()
end


function GridStatusIgnored:PARTY_MEMBERS_CHANGED()
	if not self.db.profile.alert_ignored.enable then return end
	local settings = self.db.profile.alert_ignored

	local unitname;
	
	if GridRoster then
		for guid, unitid in GridRoster:IterateRoster() do
			local unitname = UnitName(unitid);
			if unitname then
				if self:IsIgnored(unitname) then
				
					self.core:SendStatusGained(guid,
												"alert_ignored",
												settings.priority,
												nil,
												settings.color,
												settings.text,
												nil,
												nil,
												nil)
				else
					self.core:SendStatusLost(guid, "alert_ignored")
				end
			end
		end
	end
end

function GridStatusIgnored:IsIgnored(name)
	if ignoredNames[self:GetJustName(name)] then
		return true;
	end
	return nil;
end

function GridStatusIgnored:GetJustName(fullName)
    return fullName:match("(.+)%-") or fullName
end

local orig_IgnoreList_Update = IgnoreList_Update;
function IgnoreList_Update()
	orig_IgnoreList_Update();
	
	GridStatusIgnored:UpdateIgnoreList()
	GridStatusIgnored:PARTY_MEMBERS_CHANGED()
end